@@ -5,10 +5,9 @@ import os
 from django.conf import settings
 from django.http import HttpResponse
 from django.shortcuts import render
-from django.template import Context
 from django.template.loader import get_template
 from xhtml2pdf import pisa
-
+from django.contrib.staticfiles import finders
 
 try:  # python2 and python3
     from .utils import extract_request_variables
@@ -25,20 +24,24 @@ def link_callback(uri, rel):
     Convert HTML URIs to absolute system paths so xhtml2pdf can access those
     resources
     """
-    # use short variable names
-    sUrl = settings.STATIC_URL      # Typically /static/
-    sRoot = settings.STATIC_ROOT    # Typically /home/userX/project_static/
-    mUrl = settings.MEDIA_URL       # Typically /static/media/
-    # Typically /home/userX/project_static/media/
-    mRoot = settings.MEDIA_ROOT
-
-    # convert URIs to absolute system paths
-    if uri.startswith(mUrl):
-        path = os.path.join(mRoot, uri.replace(mUrl, ""))
-    elif uri.startswith(sUrl):
-        path = os.path.join(sRoot, uri.replace(sUrl, ""))
+    result = finders.find(uri)
+    if result:
+        if not isinstance(result, (list, tuple)):
+            result = [result]
+        result = list(os.path.realpath(path) for path in result)
+        path = result[0]
     else:
-        return uri  # handle absolute uri (ie: http://some.tld/foo.png)
+        sUrl = settings.STATIC_URL  # Typically /static/
+        sRoot = settings.STATIC_ROOT  # Typically /home/userX/project_static/
+        mUrl = settings.MEDIA_URL  # Typically /media/
+        mRoot = settings.MEDIA_ROOT  # Typically /home/userX/project_static/media/
+
+        if uri.startswith(mUrl):
+            path = os.path.join(mRoot, uri.replace(mUrl, ""))
+        elif uri.startswith(sUrl):
+            path = os.path.join(sRoot, uri.replace(sUrl, ""))
+        else:
+            return uri
 
     # make sure that file exists
     if not os.path.isfile(path):
@@ -47,7 +50,6 @@ def link_callback(uri, rel):
         )
     return path
 
-
 def render_pdf(request):
 
     template_path = 'user_printer.html'
@@ -57,7 +59,7 @@ def render_pdf(request):
     response['Content-Disposition'] = 'attachment; filename="report.pdf"'
 
     template = get_template(template_path)
-    html = template.render(Context(context))
+    html = template.render(context)
     if request.POST.get('show_html', ''):
         response['Content-Type'] = 'application/text'
         response['Content-Disposition'] = 'attachment; filename="report.txt"'
