@@ -1,7 +1,6 @@
 from io import BytesIO
-
+from unittest import TestCase
 import html5lib
-from nose import tools
 
 from xhtml2pdf.document import pisaDocument
 from xhtml2pdf.w3c.cssDOMElementInterface import CSSDOMElementInterface
@@ -35,17 +34,18 @@ HTML_CONTENT = """
 """
 
 
-def test_th_has_no_css_rules():
-    html = HTML_CONTENT
+class TableTest(TestCase):
+    def test_th_has_no_css_rules(self):
+        html = HTML_CONTENT
 
-    result = BytesIO()
-    pdf = pisaDocument(BytesIO(html.encode('utf-8')), result)
+        result = BytesIO()
+        pdf = pisaDocument(BytesIO(html.encode('utf-8')), result)
 
-    parser = html5lib.HTMLParser(tree=html5lib.treebuilders.getTreeBuilder("dom"))
-    document = parser.parse(html)
-    th_element = document.getElementsByTagName("th")[0]
-    th_element = CSSDOMElementInterface(th_element)
-    attr_name = "background-color"
-    rules = pdf.cssCascade.findCSSRulesFor(th_element, attr_name)
+        parser = html5lib.HTMLParser(tree=html5lib.treebuilders.getTreeBuilder("dom"))
+        document = parser.parse(html)
+        th_element = document.getElementsByTagName("th")[0]
+        th_element = CSSDOMElementInterface(th_element)
+        attr_name = "background-color"
+        rules = pdf.cssCascade.findCSSRulesFor(th_element, attr_name)
 
-    tools.assert_list_equal(rules, [])
+        self.assertEqual(rules, [])
