@@ -1,11 +1,11 @@
-import unittest
+from unittest import TestCase
 from xml.dom import minidom
 
 from xhtml2pdf import tags
 from xhtml2pdf.parser import AttrContainer
 
 
-class PisaTagTestCase(unittest.TestCase):
+class PisaTagTestCase(TestCase):
 
     def test_pisa_tag_will_set_attrs_on_init(self):
         dom = minidom.parseString("<unit>test</unit>")
