@@ -37,6 +37,7 @@ import xhtml2pdf.w3c.cssDOMElementInterface as cssDOMElementInterface
 from xhtml2pdf.xhtml2pdf_reportlab import PmlRightPageBreak, PmlLeftPageBreak
 
 
+
 CSSAttrCache = {}
 
 log = logging.getLogger("xhtml2pdf")
@@ -275,7 +276,6 @@ def CSSCollect(node, c):
                 log.debug("CSS error '%s'", cssAttrName, exc_info=1)
 
         CSSAttrCache[_key] = node.cssAttrs
-
     return node.cssAttrs
 
 
@@ -497,7 +497,6 @@ def pisaLoop(node, context, path=None, **kw):
     if node.nodeType == Node.TEXT_NODE:
         # print indent, "#", repr(node.data) #, context.frag
         context.addFrag(node.data)
-
         # context.text.append(node.value)
 
     # ELEMENT
@@ -581,7 +580,7 @@ def pisaLoop(node, context, path=None, **kw):
                         (
                             ("keepWithNext", "-pdf-keep-with-next"),
                             ("outline", "-pdf-outline"),
-                            ("borderLeftColor", "-pdf-outline-open"),
+                            #("borderLeftColor", "-pdf-outline-open"),
                         ),
                         context.cssAttr,
                         getBool
@@ -716,13 +715,16 @@ def pisaParser(src, context, default_css="", xhtml=False, encoding=None, xml_out
         parser = html5lib.XHTMLParser(tree=treebuilders.getTreeBuilder("dom"))
     else:
         parser = html5lib.HTMLParser(tree=treebuilders.getTreeBuilder("dom"))
-
+    parser_kwargs = {}
     if isinstance(src, six.text_type):
         # If an encoding was provided, do not change it.
         if not encoding:
             encoding = "utf-8"
         src = src.encode(encoding)
         src = pisaTempFile(src, capacity=context.capacity)
+        # To pass the encoding used to convert the text_type src to binary_type
+        # on to html5lib's parser to ensure proper decoding
+        parser_kwargs['transport_encoding'] = encoding
 
     # # Test for the restrictions of html5lib
     # if encoding:
@@ -736,7 +738,7 @@ def pisaParser(src, context, default_css="", xhtml=False, encoding=None, xml_out
     #         if inputstream.codecName(encoding) is None:
     #             log.error("%r is not a valid encoding", encoding)
     document = parser.parse(
-        src,
+        src, **parser_kwargs
     )  # encoding=encoding)
 
     if xml_output:
